@@ -1,4 +1,4 @@
-/* 18dec23 Software Lab. Alexander Burger */
+/* 21jan25 Software Lab. Alexander Burger */
 
 function renderCanvas(cvs, lst) {
    var ctx = cvs.getContext("2d");
@@ -249,9 +249,17 @@ function doCsMv(cvs, x, y) {
       csCursor(cvs, x - r.left, y - r.top);
    if (!cvs.csDn)
       return true;
-   if (drawCanvas(cvs.id, cvs.dly, cvs.csMv? -1 : 0, cvs.csDnX, cvs.csDnY, x - r.left, y - r.top))
-      return true;
-   cvs.csMv = true;
+   if (!cvs.csMv)
+      cvs.csMv = [x, y];
+   else {
+      if (Array.isArray(cvs.csMv)) {
+         if (drawCanvas(cvs.id, cvs.dly, 0, cvs.csDnX, cvs.csDnY, cvs.csMv[0] - r.left, cvs.csMv[1] - r.top))
+            return true;
+         cvs.csMv = true;
+      }
+      if (drawCanvas(cvs.id, cvs.dly, -1, cvs.csDnX, cvs.csDnY, x - r.left, y - r.top))
+         return true;
+   }
    return false;
 }
 
