@@ -1,4 +1,4 @@
-/* 05oct23 Software Lab. Alexander Burger */
+/* 13mar25 Software Lab. Alexander Burger */
 
 var Btn = [];
 var SesId, Key, InBtn, Auto, Chg, Post, Drop, Hint, Hints, Item, Beg, End;
@@ -6,27 +6,27 @@ var SesId, Key, InBtn, Auto, Chg, Post, Drop, Hint, Hints, Item, Beg, End;
 function inBtn(btn,flg) {InBtn = flg;}
 
 function formKey(event) {
-   Key = event.keyCode;
-   if (Hint  &&  event.charCode == 0  &&  Hint.style.visibility == "visible") {
-      if ((Item >= 0 && Key == 13) || Key == 38 || Key == 40)
+   Key = event.key;
+   if (Hint  &&  Hint.style.visibility == "visible") {
+      if ((Item >= 0  &&  Key == "Enter")  ||  Key == "ArrowUp"  ||  Key == "ArrowDown")
          return false;
-      if (Key == 13) {
+      if (Key == "Enter") {
          Hint.style.visibility = "hidden";
          return true;
       }
-      if (Key == 27) {
+      if (Key == "Escape") {
          Hint.style.visibility = "hidden";
          return false;
       }
    }
-   if (event.charCode || Key == 8)
+   if (Key == "Backspace")
       Chg = true;
    return true;
 }
 
 function fldChg(field) {
    Chg = true;
-   if (!InBtn && (Key != 13 || field.type == "textarea")) {
+   if (!InBtn  &&  (Key != "Enter" || field.type == "textarea")) {
       post(field.form, false, null, null);
       Key = 0;
    }
@@ -381,21 +381,21 @@ function doHint(field) {
 function hintKey(field, event, tok, coy) {
    var i, data;
 
-   if (event.keyCode == 9 || event.keyCode == 27)
+   if (event.key == "Tab"  ||  event.key == "Escape")
       return false;
-   if (event.charCode == 0  &&  Hint.style.visibility == "visible") {
-      if (Item >= 0 && event.keyCode == 13) {
+   if (Hint.style.visibility == "visible") {
+      if (Item >= 0  &&  event.key == "Enter") {
          setHint(field, Hints.childNodes[Item]);
          return false;
       }
-      if (event.keyCode == 38) {  // Up
+      if (event.key == "ArrowUp") {
          if (Item > 0) {
             hintOff(Item);
             hintOn(--Item);
          }
          return false;
       }
-      if (event.keyCode == 40) {  // Down
+      if (event.key == "ArrowDown") {
          if (Item < (lst = Hints.childNodes).length-1) {
             if (Item >= 0)
                hintOff(Item);
@@ -404,7 +404,7 @@ function hintKey(field, event, tok, coy) {
          return false;
       }
    }
-   if (event.keyCode == 13)
+   if (event.key == "Enter")
       return true;
    var req = new XMLHttpRequest();
    if (tok) {
@@ -415,7 +415,7 @@ function hintKey(field, event, tok, coy) {
       Beg = 0;
       End = field.value.length;
    }
-   if (event.keyCode != 45) {  // INS
+   if (event.key != "Insert") {
       if (Beg == End) {
          Hint.style.visibility = "hidden";
          return false;
@@ -463,7 +463,7 @@ function hintKey(field, event, tok, coy) {
       req.abort();
       return true;
    }
-   return (event.keyCode != 45);  // INS
+   return (event.key != "Insert");
 }
 
 function addHint(i, field, str) {
@@ -518,19 +518,25 @@ function hintOff(i) {
 }
 
 /*** Scroll/touch ***/
-var TblY;
+var TblX, TblY;
 
 function tblTouch(event) {
-   if (event.touches.length == 1)
+   if (event.touches.length == 1) {
+      TblX = event.touches[0].pageX;
       TblY = event.touches[0].pageY;
+   }
    return true;
 }
 
 function tblMove(table, event) {
    if (event.touches.length == 1) {
+      var dx = event.touches[0].pageX - TblX;
       var dy = event.touches[0].pageY - TblY;
 
-      if (dy < -12 || dy > +12) {
+      TblX = event.touches[0].pageX;
+      if (Math.abs(dx) > Math.abs(dy))
+         return true;
+      if (Math.abs(dy) > 12) {
          TblY = event.touches[0].pageY;
          for (var obj = table.parentNode;  obj;  obj = obj.parentNode)
             if (obj.tagName == "FORM")
